TaskUpdate class sealed

Base class for updates related to task. Actual updates are either a status update or a progress update.

When receiving an update, test if the update is a TaskStatusUpdate or a TaskProgressUpdate and treat the update accordingly

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task Task
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return JSON Map representing object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited