HlsDownloadOptions class

Constructors

HlsDownloadOptions({String? downloadId, int retryAttempts = 3, Map<String, String> customHeaders = const {}, HlsVariantSelection variantSelection = HlsVariantSelection.highestBandwidth, bool combineSegments = true, bool deleteSegmentsAfterCombine = true, bool keepTempFilesOnFailure = false, String outputFileExtension = 'mp4', String? outputDirectoryPath, BatchProgressCallback? batchProgressCallback, HlsLogLevel logLevel = HlsLogLevel.error, HlsLogCallback? logCallback})
const

Properties

batchProgressCallback BatchProgressCallback?
final
combineSegments bool
final
customHeaders Map<String, String>
final
deleteSegmentsAfterCombine bool
final
downloadId String?
final
hashCode int
The hash code for this object.
no setterinherited
keepTempFilesOnFailure bool
final
logCallback HlsLogCallback?
final
logLevel HlsLogLevel
final
outputDirectoryPath String?
final
outputFileExtension String
final
retryAttempts int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variantSelection HlsVariantSelection
final

Methods

copyWith({String? downloadId, int? retryAttempts, Map<String, String>? customHeaders, HlsVariantSelection? variantSelection, bool? combineSegments, bool? deleteSegmentsAfterCombine, bool? keepTempFilesOnFailure, String? outputFileExtension, String? outputDirectoryPath, BatchProgressCallback? batchProgressCallback, HlsLogLevel? logLevel, HlsLogCallback? logCallback}) HlsDownloadOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited