HlsErrorCode class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- combineFailed → const String
- downloadAlreadyRunning → const String
- downloadCanceled → const String
- downloadNotFound → const String
- downloadPaused → const String
- emptyPlaylist → const String
- encryptionKeyFetchFailed → const String
- invalidFileName → const String
- invalidOptions → const String
- invalidUrl → const String
- playlistParseFailed → const String
- segmentDownloadFailed → const String
- segmentMissing → const String
- storagePermissionDenied → const String
- unexpected → const String