HlsResolvedManifest class

Constructors

HlsResolvedManifest({required Uri originalManifestUri, required Uri mediaPlaylistUri, required List<HlsSegmentEntry> segments})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mediaPlaylistUri Uri
final
originalManifestUri Uri
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<HlsSegmentEntry>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited