DownloaderHelper class
Constructors
- DownloaderHelper({Client? httpClient})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildOutputFileName(
String fileName, String defaultExtension) → String -
combineSegmentsToFile(
{required List< HlsSegmentEntry> segments, required String segmentDirectoryPath, required String outputFilePath, required Map<String, String> customHeaders}) → Future<void> -
dispose(
) → void -
generateId(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveManifest(
{required String manifestUrl, required Map< String, String> customHeaders, required HlsVariantSelection variantSelection}) → Future<HlsResolvedManifest> -
sanitizeFileName(
String fileName) → String -
segmentFileName(
int index) → String -
toString(
) → String -
A string representation of this object.
inherited
-
validateDownloadRequest(
{required String manifestUrl, required String fileName, required HlsDownloadOptions options}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited