HlsDownloadResult class
Constructors
- HlsDownloadResult({required String downloadId, required String? finalTaskId, required String manifestUrl, required String resolvedMediaPlaylistUrl, required String segmentDirectoryPath, required String? outputFilePath, required int segmentCount, required int failedSegmentCount, required Batch batch})
-
const
Properties
- batch → Batch
-
final
- downloadId → String
-
final
- failedSegmentCount → int
-
final
- finalTaskId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- manifestUrl → String
-
final
- outputFilePath → String?
-
final
- resolvedMediaPlaylistUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentCount → int
-
final
- segmentDirectoryPath → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited