HlsOverallTaskUpdate class
Constructors
- HlsOverallTaskUpdate({required String downloadId, required HlsDownloadPhase phase, required int totalSegments, required int completedSegments, required int failedSegments, required double progress, int? totalExpectedFileSize, int? downloadedBytes, double? networkSpeed, Duration? timeRemaining, String? message, TaskUpdate? latestTaskUpdate})
-
const
Properties
- completedSegments → int
-
final
- downloadedBytes → int?
-
final
- downloadId → String
-
final
- failedSegments → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTerminal → bool
-
no setter
- latestTaskUpdate → TaskUpdate?
-
final
- message → String?
-
final
- networkSpeed → double?
-
final
- phase → HlsDownloadPhase
-
final
- progress → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeRemaining → Duration?
-
final
- totalExpectedFileSize → int?
-
final
- totalSegments → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited